==> humhub-1.15.3.tar.gz: humhub-1.15.3/protected/humhub/messages/ru/base.php <==
<?php
return array (
  '<strong>Confirm</strong> Action' => '<strong>Подтвержите действие</strong>',
  '<strong>Latest</strong> updates' => '<strong>Последние</strong> обновления',
  '<strong>Mail</strong> summary' => '<strong>Email рассылка</strong>',
  'Actions' => 'Действия',
  'Add:' => 'Добавить:',
  'Administration' => 'Администрирование',
  'All' => 'Все',
  'Allow' => 'Разрешено',
  'Allow content from external source' => 'Разрешить доступ к контенту из внешнего источника',
  'Always allow content from this provider!' => 'Всегда разрешайте контент от этого поставщика!',
  'An error occurred while handling your last action. (Handler not found).' => 'Произошла ошибка при обработке вашего последнего действия. (Обработчик не найден).',
  'An unexpected error occurred while loading the search result.' => 'Произошла непредвиденная ошибка при загрузке результата поиска.',
  'An unexpected error occurred. If this keeps happening, please contact a site administrator.' => 'Произошла непредвиденная ошибка. Если это повторяется постоянно, обратитесь к администратору сайта.',
  'An unexpected error occurred. Please check whether your file exceeds the allowed upload limit of {maxUploadSize}.' => 'Произошла непредвиденная ошибка. Проверьте, не превышает ли ваш файл разрешенный лимит загрузки {maxUploadSize}.',
  'An unexpected server error occurred. If this keeps happening, please contact a site administrator.' => 'Произошла непредвиденная ошибка сервера. Если это повторяется постоянно, обратитесь к администратору сайта.',
  'Back' => 'Назад',
  'Back to dashboard' => 'Вернуться на главную',
  'Cancel' => 'Отменить',
  'Choose language:' => 'Выберите язык:',
  'Close' => 'Закрыть',
  'Collapse' => 'Свернуть',
  'Confirm' => 'Подтвердить',
  'Content Addon source must be instance of HActiveRecordContent or HActiveRecordContentAddon!' => 'Источник Content Addon должен быть сущностью HActiveRecordContent либо HActiveRecordContentAddon!',
  'Copy to clipboard' => 'Скопировано в буфер обмена',
  'Could not find content of addon!' => 'Не удалось найти содержимое аддона!',
  'Could not find requested page.' => 'Не удалось найти запрашиваемую страницу.',
  'Default' => 'По умолчанию',
  'Delete' => 'Удалить',
  'Deny' => 'Запрещено',
  'Do you really want to perform this action?' => 'Вы уверены, что хотите выполнить это действие?',
  'Do you want to enable content from \'{urlPrefix}\'?' => 'Вы хотите включить содержимое из \'{urlPrefix}\'?',
  'Edit' => 'Изменить',
  'Error' => 'Ошибка',
  'Error while running your last action (Invalid request method).' => 'Ошибка при выполнении Вашего последнего действия (Неверный запрос).',
  'Error:' => 'Ошибка:',
  'Expand' => 'Развернуть',
  'Export' => 'Экспорт',
  'Info:' => 'Информация:',
  'Invalid request method!' => 'Неверный запрос!',
  'It looks like you may have taken the wrong turn.' => 'Похоже, что Вы сделали что-то не так.',
  'Language' => 'Язык',
  'Loading...' => 'Загрузка...',
  'Login' => 'Войти',
  'Logo of {appName}' => 'Логотип {appName}',
  'Logout' => 'Выйти',
  'Menu' => 'Меню',
  'Module is not enabled on this content container!' => 'Модуль не включён в этой оболочке контента!',
  'My Profile' => 'Мой профиль',
  'New profile image' => 'Новое изображение профиля',
  'Next' => 'Следующий',
  'No error information given.' => 'Информация об ошибке не указана.',
  'Oooops...' => 'Ой...',
  'Open' => 'Открыть',
  'Please type at least 3 characters' => 'Пожалуйста, введите не менее 3-х символов',
  'Please type at least {count} characters' => 'Пожалуйста, введите не менее {count} символов',
  'Powered by {name}' => 'Работает на {name}',
  'Profile dropdown' => 'Раскрывающийся профиль',
  'Profile picture of {displayName}' => 'Аватар пользователя {displayName}',
  'Save' => 'Сохранить',
  'Saved' => 'Сохранено',
  'Search' => 'Поиск',
  'Search...' => 'Поиск...',
  'Select Me' => 'Выбери',
  'Settings' => 'Настройки',
  'Show less' => 'Показать меньше',
  'Show more' => 'Показать больше',
  'Some files could not be uploaded:' => 'Некоторые файлы не могут быть загружены:',
  'Stop impersonation' => 'Прекратите выдавать себя за другого',
  'Text could not be copied to clipboard' => 'Текст не может быть скопирован в буфер обмена',
  'Text has been copied to clipboard' => 'Текст скопирован в буфер обмена',
  'The date has to be in the past.' => 'Дата должна быть в прошлом.',
  'The file has been deleted.' => 'Файл был удалён.',
  'The requested resource could not be found.' => 'Запрошенный ресурс не найден.',
  'The space has been archived.' => 'Пространство было архивировано.',
  'The space has been unarchived.' => 'Пространство было разархивировано.',
  'Time Zone' => 'Часовой пояс',
  'Toggle comment menu' => 'Переключить меню комментариев',
  'Toggle panel menu' => 'Переключить панель меню',
  'Toggle post menu' => 'Переключить меню записей',
  'Toggle stream entry menu' => 'Переключить меню ленты',
  'Unsaved changes will be lost. Do you want to proceed?' => 'Есть несохраненные изменения, Вы действительно хотите покинуть эту страницу?',
  'Unsubscribe' => 'Отписаться',
  'Upload' => 'Загрузить',
  'Upload file' => 'Загрузить файл',
  'You are not allowed to run this action.' => 'Вы не можете запускать это действие.',
  'verify your upload_max_filesize and post_max_size php settings.' => 'проверьте настройки PHP upload_max_filesize и post_max_size.',
  '{attribute} has been empty. The system-configured function to fill empty values has returned an invalid value. Please try again or contact your administrator.' => '{attribute} пуст. Настроенная системой функция для заполнения пустых значений вернула недопустимое значение. Пожалуйста, попробуйте еще раз или обратитесь к администратору.',
  '{attribute} must be a string (UUID) or null; {type} given.' => '{attribute} должен быть строкой (UUID) или нулевым значением; Указан {type}.',
  '{attribute} must be an UUID or null. UUID has the format "{{XXXXXXXX-XXXX-XXXX-XXXX-XXXXXXXXXXXX}}", where X = [a-fA-F0-9] and both curly brackets and delimiting dashes are optional.' => '{attribute} должен быть UUID или нулевым. UUID имеет формат «{{XXXXXXXX-XXXX-XXXX-XXXX-XXXXXXXXXXXX}}», где X = [a-fA-F0-9], а фигурные скобки и разделительные тире являются необязательными.',
  '{nFormatted}B' => '{nFormatted}B',
  '{nFormatted}K' => '{nFormatted}K',
  '{nFormatted}M' => '{nFormatted}M',
);

==> humhub-1.16.2.tar.gz: humhub-1.16.2/protected/humhub/messages/ru/base.php <==
<?php
return array (
  '<strong>Confirm</strong> Action' => '<strong>Подтвердите</strong> действие',
  '<strong>Latest</strong> updates' => '<strong>Последние</strong> обновления',
  '<strong>Mail</strong> summary' => '<strong>Email рассылка</strong>',
  'Actions' => 'Действия',
  'Add:' => 'Добавить:',
  'Administration' => 'Администрирование',
  'All' => 'Все',
  'Allow' => 'Разрешено',
  'Allow content from external source' => 'Разрешить доступ к контенту из внешнего источника',
  'Always allow content from this provider!' => 'Всегда разрешайте контент от этого поставщика!',
  'An error occurred while handling your last action. (Handler not found).' => 'Произошла ошибка при обработке вашего последнего действия. (Обработчик не найден).',
  'An unexpected error occurred while loading the search result.' => 'Произошла непредвиденная ошибка при загрузке результата поиска.',
  'An unexpected error occurred. If this keeps happening, please contact a site administrator.' => 'Произошла непредвиденная ошибка. Если это повторяется постоянно, обратитесь к администратору сайта.',
  'An unexpected error occurred. Please check whether your file exceeds the allowed upload limit of {maxUploadSize}.' => 'Произошла непредвиденная ошибка. Проверьте, не превышает ли ваш файл разрешенный лимит загрузки {maxUploadSize}.',
  'An unexpected server error occurred. If this keeps happening, please contact a site administrator.' => 'Произошла непредвиденная ошибка сервера. Если это повторяется постоянно, обратитесь к администратору сайта.',
  'Back' => 'Назад',
  'Back to dashboard' => 'Вернуться на главную',
  'Cancel' => 'Отменить',
  'Choose language:' => 'Выберите язык:',
  'Close' => 'Закрыть',
  'Collapse' => 'Свернуть',
  'Confirm' => 'Подтвердить',
  'Content Addon source must be instance of HActiveRecordContent or HActiveRecordContentAddon!' => 'Источник Content Addon должен быть сущностью HActiveRecordContent либо HActiveRecordContentAddon!',
  'Copy to clipboard' => 'Скопировать в буфер обмена',
  'Could not find content of addon!' => 'Не удалось найти содержимое аддона!',
  'Could not find requested page.' => 'Не удалось найти запрашиваемую страницу.',
  'Default' => 'По умолчанию',
  'Delete' => 'Удалить',
  'Deny' => 'Запрещено',
  'Do you really want to perform this action?' => 'Вы уверены, что хотите выполнить это действие?',
  'Do you want to enable content from \'{urlPrefix}\'?' => 'Вы хотите включить содержимое из \'{urlPrefix}\'?',
  'Edit' => 'Изменить',
  'Error' => 'Ошибка',
  'Error while running your last action (Invalid request method).' => 'Ошибка при выполнении Вашего последнего действия (Неверный запрос).',
  'Error:' => 'Ошибка:',
  'Expand' => 'Развернуть',
  'Export' => 'Экспорт',
  'Info:' => 'Информация:',
  'Invalid request method!' => 'Неверный запрос!',
  'It looks like you may have taken the wrong turn.' => 'Похоже, что Вы сделали что-то не так.',
  'Language' => 'Язык',
  'Loading...' => 'Загрузка...',
  'Login' => 'Войти',
  'Logo of {appName}' => 'Логотип {appName}',
  'Logout' => 'Выйти',
  'Menu' => 'Меню',
  'Module is not enabled on this content container!' => 'Модуль не включён в этой оболочке контента!',
  'My Profile' => 'Мой профиль',
  'New profile image' => 'Новое изображение профиля',
  'Next' => 'Следующий',
  'No error information given.' => 'Информация об ошибке не указана.',
  'No results' => 'Нет результатов',
  'Oooops...' => 'Ой...',
  'Open' => 'Открыть',
  'Please type at least 3 characters' => 'Пожалуйста, введите не менее 3-х символов',
  'Please type at least {count} characters' => 'Пожалуйста, введите не менее {count} символов',
  'Powered by {name}' => 'Работает на {name}',
  'Profile dropdown' => 'Раскрывающийся профиль',
  'Profile picture of {displayName}' => 'Аватар пользователя {displayName}',
  'Save' => 'Сохранить',
  'Saved' => 'Сохранено',
  'Search' => 'Поиск',
  'Search...' => 'Поиск...',
  'Select Me' => 'Выбери',
  'Settings' => 'Настройки',
  'Show all results' => 'Показать все результаты',
  'Show less' => 'Показать меньше',
  'Show more' => 'Показать больше',
  'Some files could not be uploaded:' => 'Некоторые файлы не могут быть загружены:',
  'Stop impersonation' => 'Прекратите выдавать себя за другого',
  'Text could not be copied to clipboard' => 'Текст не может быть скопирован в буфер обмена',
  'Text has been copied to clipboard' => 'Текст скопирован в буфер обмена',
  'The date has to be in the past.' => 'Дата должна быть в прошлом.',
  'The file has been deleted.' => 'Файл был удалён.',
  'The requested resource could not be found.' => 'Запрошенный ресурс не найден.',
  'The space has been archived.' => 'Пространство было архивировано.',
  'The space has been unarchived.' => 'Пространство было разархивировано.',
  'Time Zone' => 'Часовой пояс',
  'Toggle comment menu' => 'Переключить меню комментариев',
  'Toggle panel menu' => 'Переключить панель меню',
  'Toggle post menu' => 'Переключить меню записей',
  'Toggle stream entry menu' => 'Переключить меню ленты',
  'Unsaved changes will be lost. Do you want to proceed?' => 'Есть несохраненные изменения, Вы действительно хотите покинуть эту страницу?',
  'Unsubscribe' => 'Отписаться',
  'Upload' => 'Загрузить',
  'Upload file' => 'Загрузить файл',
  'You are not allowed to run this action.' => 'Вы не можете запускать это действие.',
  'verify your upload_max_filesize and post_max_size php settings.' => 'проверьте настройки PHP upload_max_filesize и post_max_size.',
  '{attribute} has been empty. The system-configured function to fill empty values has returned an invalid value. Please try again or contact your administrator.' => '{attribute} пуст. Настроенная системой функция для заполнения пустых значений вернула недопустимое значение. Пожалуйста, попробуйте еще раз или обратитесь к администратору.',
  '{attribute} must be a string (UUID) or null; {type} given.' => '{attribute} должен быть строкой (UUID) или нулевым значением; Указан {type}.',
  '{attribute} must be an UUID or null. UUID has the format "{{XXXXXXXX-XXXX-XXXX-XXXX-XXXXXXXXXXXX}}", where X = [a-fA-F0-9] and both curly brackets and delimiting dashes are optional.' => '{attribute} должен быть UUID или нулевым. UUID имеет формат «{{XXXXXXXX-XXXX-XXXX-XXXX-XXXXXXXXXXXX}}», где X = [a-fA-F0-9], а фигурные скобки и разделительные тире являются необязательными.',
  '{nFormatted}B' => '{nFormatted}B',
  '{nFormatted}K' => '{nFormatted}K',
  '{nFormatted}M' => '{nFormatted}M',
);
